#
# Configuration file for using the xslt library
#
XSLT_LIBDIR="-L/usr/lib32"
XSLT_LIBS="-lxslt -lxml2  "
XSLT_PRIVATE_LIBS="-lm"
XSLT_INCLUDEDIR="-I/usr/include"
MODULE_VERSION="xslt-1.1.37"
